@@ -38,6 +38,8 @@
 #include "io.hpp"
 #include "metadata.hpp"
 
+#include "proj.h"
+
 NS_PROJ_START
 
 namespace crs {
@@ -49,6 +51,10 @@ class DerivedCRS;
 class ProjectedCRS;
 } // namespace crs
 
+namespace io {
+class JSONParser;
+} // namespace io
+
 namespace coordinates {
 class CoordinateMetadata;
 using CoordinateMetadataPtr = std::shared_ptr<CoordinateMetadata>;
@@ -99,6 +105,45 @@ using CoordinateOperationPtr = std::shared_ptr<CoordinateOperation>;
 /** Non-null shared pointer of CoordinateOperation */
 using CoordinateOperationNNPtr = util::nn<CoordinateOperationPtr>;
 
+// ---------------------------------------------------------------------------
+
+class CoordinateTransformer;
+/** Shared pointer of CoordinateTransformer */
+using CoordinateTransformerPtr = std::unique_ptr<CoordinateTransformer>;
+/** Non-null shared pointer of CoordinateTransformer */
+using CoordinateTransformerNNPtr = util::nn<CoordinateTransformerPtr>;
+
+/** \brief Coordinate transformer.
+ *
+ * Performs coordinate transformation of coordinate tuplies.
+ *
+ * @since 9.3
+ */
+class PROJ_GCC_DLL CoordinateTransformer {
+  public:
+    //! @cond Doxygen_Suppress
+    PROJ_DLL ~CoordinateTransformer();
+    //! @endcond
+
+    PROJ_DLL PJ_COORD transform(PJ_COORD coord);
+
+  protected:
+    PROJ_FRIEND(CoordinateOperation);
+
+    PROJ_INTERNAL CoordinateTransformer();
+
+    PROJ_INTERNAL static CoordinateTransformerNNPtr
+    create(const CoordinateOperationNNPtr &op, PJ_CONTEXT *ctx);
+
+  private:
+    PROJ_OPAQUE_PRIVATE_DATA
+    INLINED_MAKE_UNIQUE
+    CoordinateTransformer &
+    operator=(const CoordinateTransformer &other) = delete;
+};
+
+// ---------------------------------------------------------------------------
+
 class Transformation;
 /** Shared pointer of Transformation */
 using TransformationPtr = std::shared_ptr<Transformation>;
@@ -147,7 +192,8 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
     PROJ_DLL const util::optional<common::DataEpoch> &
     targetCoordinateEpoch() const;
 
-    // virtual void transform(...) = 0;  TODO
+    PROJ_DLL CoordinateTransformerNNPtr
+    coordinateTransformer(PJ_CONTEXT *ctx) const;
 
     /** \brief Return the inverse of the coordinate operation.
      * @throw util::UnsupportedOperationException
@@ -184,6 +230,7 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
     PROJ_FRIEND(CoordinateOperationFactory);
     PROJ_FRIEND(ConcatenatedOperation);
     PROJ_FRIEND(io::WKTParser);
+    PROJ_FRIEND(io::JSONParser);
     PROJ_INTERNAL void
     setWeakSourceTargetCRS(std::weak_ptr<crs::CRS> sourceCRSIn,
                            std::weak_ptr<crs::CRS> targetCRSIn);
@@ -675,6 +722,10 @@ class PROJ_GCC_DLL SingleOperation : virtual public CoordinateOperation {
                                        const io::DatabaseContextPtr &dbContext,
                                        bool inOtherDirection) const;
 
+    PROJ_INTERNAL static GeneralParameterValueNNPtr
+    createOperationParameterValueFromInterpolationCRS(int methodEPSGCode,
+                                                      int crsEPSGCode);
+
   private:
     PROJ_OPAQUE_PRIVATE_DATA
     SingleOperation &operator=(const SingleOperation &other) = delete;
@@ -976,6 +1027,14 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Length &falseEasting,
         const common::Length &falseNorthing);
 
+    PROJ_DLL static ConversionNNPtr createLambertConicConformal_1SP_VariantB(
+        const util::PropertyMap &properties,
+        const common::Angle &latitudeNatOrigin, const common::Scale &scale,
+        const common::Angle &latitudeFalseOrigin,
+        const common::Angle &longitudeFalseOrigin,
+        const common::Length &eastingFalseOrigin,
+        const common::Length &northingFalseOrigin);
+
     PROJ_DLL static ConversionNNPtr
     createLambertConicConformal_2SP(const util::PropertyMap &properties,
                                     const common::Angle &latitudeFalseOrigin,
@@ -1046,12 +1105,12 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
 
     PROJ_DLL static ConversionNNPtr
     createEquidistantConic(const util::PropertyMap &properties,
-                           const common::Angle &centerLat,
-                           const common::Angle &centerLong,
+                           const common::Angle &latitudeFalseOrigin,
+                           const common::Angle &longitudeFalseOrigin,
                            const common::Angle &latitudeFirstParallel,
                            const common::Angle &latitudeSecondParallel,
-                           const common::Length &falseEasting,
-                           const common::Length &falseNorthing);
+                           const common::Length &eastingFalseOrigin,
+                           const common::Length &northingFalseOrigin);
 
     PROJ_DLL static ConversionNNPtr
     createEckertI(const util::PropertyMap &properties,
@@ -1233,6 +1292,11 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Angle &centerLong, const common::Length &falseEasting,
         const common::Length &falseNorthing);
 
+    PROJ_DLL static ConversionNNPtr createMercatorSpherical(
+        const util::PropertyMap &properties, const common::Angle &centerLat,
+        const common::Angle &centerLong, const common::Length &falseEasting,
+        const common::Length &falseNorthing);
+
     PROJ_DLL static ConversionNNPtr
     createMollweide(const util::PropertyMap &properties,
                     const common::Angle &centerLong,
@@ -1766,7 +1830,8 @@ class PROJ_GCC_DLL ConcatenatedOperation final : public CoordinateOperation {
     PROJ_INTERNAL static void
     fixStepsDirection(const crs::CRSNNPtr &concatOpSourceCRS,
                       const crs::CRSNNPtr &concatOpTargetCRS,
-                      std::vector<CoordinateOperationNNPtr> &operationsInOut);
+                      std::vector<CoordinateOperationNNPtr> &operationsInOut,
+                      const io::DatabaseContextPtr &dbContext);
     //! @endcond
 
   protected:
