@@ -69,6 +69,7 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage,
     //! @endcond
 
     PROJ_DLL const util::optional<std::string> &anchorDefinition() const;
+    PROJ_DLL const util::optional<common::Measure> &anchorEpoch() const;
     PROJ_DLL const util::optional<common::DateTime> &publicationDate() const;
     PROJ_DLL const common::IdentifiedObjectPtr &conventionalRS() const;
 
@@ -91,6 +92,8 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage,
 
   protected:
     PROJ_INTERNAL void setAnchor(const util::optional<std::string> &anchor);
+    PROJ_INTERNAL void
+    setAnchorEpoch(const util::optional<common::Measure> &anchorEpoch);
 
     PROJ_INTERNAL void
     setProperties(const util::PropertyMap
@@ -414,6 +417,12 @@ class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
            const util::optional<std::string> &anchor,
            const PrimeMeridianNNPtr &primeMeridian);
 
+    PROJ_DLL static GeodeticReferenceFrameNNPtr
+    create(const util::PropertyMap &properties, const EllipsoidNNPtr &ellipsoid,
+           const util::optional<std::string> &anchor,
+           const util::optional<common::Measure> &anchorEpoch,
+           const PrimeMeridianNNPtr &primeMeridian);
+
     PROJ_DLL static const GeodeticReferenceFrameNNPtr
         EPSG_6267; // North American Datum 1927
     PROJ_DLL static const GeodeticReferenceFrameNNPtr
@@ -432,6 +441,10 @@ class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
         util::IComparable::Criterion criterion =
             util::IComparable::Criterion::STRICT,
         const io::DatabaseContextPtr &dbContext = nullptr) const override;
+
+    PROJ_INTERNAL bool isEquivalentToNoExactTypeCheck(
+        const util::IComparable *other, util::IComparable::Criterion criterion,
+        const io::DatabaseContextPtr &dbContext) const;
     //! @endcond
 
   protected:
@@ -580,6 +593,13 @@ class PROJ_GCC_DLL VerticalReferenceFrame : public Datum {
            const util::optional<RealizationMethod> &realizationMethodIn =
                util::optional<RealizationMethod>());
 
+    PROJ_DLL static VerticalReferenceFrameNNPtr
+    create(const util::PropertyMap &properties,
+           const util::optional<std::string> &anchor,
+           const util::optional<common::Measure> &anchorEpoch,
+           const util::optional<RealizationMethod> &realizationMethodIn =
+               util::optional<RealizationMethod>());
+
     //! @cond Doxygen_Suppress
     PROJ_INTERNAL bool _isEquivalentTo(
         const util::IComparable *other,
@@ -587,6 +607,10 @@ class PROJ_GCC_DLL VerticalReferenceFrame : public Datum {
             util::IComparable::Criterion::STRICT,
         const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
+    PROJ_INTERNAL bool isEquivalentToNoExactTypeCheck(
+        const util::IComparable *other, util::IComparable::Criterion criterion,
+        const io::DatabaseContextPtr &dbContext) const;
+
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
