@@ -33,6 +33,11 @@
 #error Must have C++11 or newer.
 #endif
 
+// windows.h can conflict with Criterion::STRICT
+#ifdef STRICT
+#undef STRICT
+#endif
+
 #include <exception>
 #include <map>
 #include <memory>
@@ -50,10 +55,12 @@ namespace proj {}
 //! @cond Doxygen_Suppress
 
 #ifndef PROJ_DLL
+#if defined(_MSC_VER)
 #ifdef PROJ_MSVC_DLL_EXPORT
 #define PROJ_DLL __declspec(dllexport)
-#elif defined(PROJ_MSVC_DLL_IMPORT)
+#else
 #define PROJ_DLL __declspec(dllimport)
+#endif
 #elif defined(__GNUC__)
 #define PROJ_DLL __attribute__((visibility("default")))
 #else
@@ -62,12 +69,7 @@ namespace proj {}
 #endif
 
 #ifndef PROJ_MSVC_DLL
-
-#ifdef PROJ_MSVC_DLL_EXPORT
-#define PROJ_MSVC_DLL PROJ_DLL
-#define PROJ_GCC_DLL
-#define PROJ_INTERNAL
-#elif defined(PROJ_MSVC_DLL_IMPORT)
+#if defined(_MSC_VER)
 #define PROJ_MSVC_DLL PROJ_DLL
 #define PROJ_GCC_DLL
 #define PROJ_INTERNAL
@@ -84,9 +86,7 @@ namespace proj {}
 #define PROJ_GCC_DLL
 #define PROJ_INTERNAL
 #endif
-
 #define PROJ_FOR_TEST PROJ_DLL
-
 #endif
 
 #include "nn.hpp"
@@ -130,11 +130,11 @@ namespace proj {}
 // to be able to call make_shared on a protected/private constructor
 #define INLINED_MAKE_SHARED                                                    \
     template <typename T, typename... Args>                                    \
-    static std::shared_ptr<T> make_shared(Args &&... args) {                   \
+    static std::shared_ptr<T> make_shared(Args &&...args) {                    \
         return std::shared_ptr<T>(new T(std::forward<Args>(args)...));         \
     }                                                                          \
     template <typename T, typename... Args>                                    \
-    static util::nn_shared_ptr<T> nn_make_shared(Args &&... args) {            \
+    static util::nn_shared_ptr<T> nn_make_shared(Args &&...args) {             \
         return util::nn_shared_ptr<T>(                                         \
             util::i_promise_i_checked_for_null,                                \
             std::shared_ptr<T>(new T(std::forward<Args>(args)...)));           \
@@ -144,7 +144,7 @@ namespace proj {}
 // to be able to call make_unique on a protected/private constructor
 #define INLINED_MAKE_UNIQUE                                                    \
     template <typename T, typename... Args>                                    \
-    static std::unique_ptr<T> make_unique(Args &&... args) {                   \
+    static std::unique_ptr<T> make_unique(Args &&...args) {                    \
         return std::unique_ptr<T>(new T(std::forward<Args>(args)...));         \
     }
 
@@ -180,7 +180,7 @@ NS_PROJ_START
 namespace io {
 class DatabaseContext;
 using DatabaseContextPtr = std::shared_ptr<DatabaseContext>;
-}
+} // namespace io
 //! @endcond
 
 /** osgeo.proj.util namespace.
@@ -331,6 +331,7 @@ class PROJ_GCC_DLL BaseObject {
   protected:
     PROJ_INTERNAL BaseObject();
     PROJ_INTERNAL void assignSelf(const BaseObjectNNPtr &self);
+    PROJ_INTERNAL BaseObject &operator=(BaseObject &&other);
 
   private:
     PROJ_OPAQUE_PRIVATE_DATA
@@ -555,8 +556,8 @@ using GenericNameNNPtr = util::nn<GenericNamePtr>;
 /** \brief A sequence of identifiers rooted within the context of a namespace.
  *
  * \remark Simplified version of [GenericName]
- * (http://www.geoapi.org/3.0/javadoc/org/opengis/util/GenericName.html) from
- * \ref GeoAPI
+ * (http://www.geoapi.org/3.0/javadoc/org.opengis.geoapi/org/opengis/util/GenericName.html)
+ * from \ref GeoAPI
  */
 class GenericName : public BaseObject {
   public:
@@ -590,8 +591,8 @@ class GenericName : public BaseObject {
 /** \brief A domain in which names given by strings are defined.
  *
  * \remark Simplified version of [NameSpace]
- * (http://www.geoapi.org/3.0/javadoc/org/opengis/util/NameSpace.html) from \ref
- * GeoAPI
+ * (http://www.geoapi.org/3.0/javadoc/org.opengis.geoapi/org/opengis/util/NameSpace.html)
+ * from \ref GeoAPI
  */
 class NameSpace {
   public:
@@ -627,8 +628,8 @@ class NameSpace {
  * NameSpace within which they are local, indicated by the scope.
  *
  * \remark Simplified version of [LocalName]
- * (http://www.geoapi.org/3.0/javadoc/org/opengis/util/LocalName.html) from \ref
- * GeoAPI
+ * (http://www.geoapi.org/3.0/javadoc/org.opengis.geoapi/org/opengis/util/LocalName.html)
+ * from \ref GeoAPI
  */
 class LocalName : public GenericName {
   public:
@@ -658,8 +659,8 @@ class LocalName : public GenericName {
 /** \brief Factory for generic names.
  *
  * \remark Simplified version of [NameFactory]
- * (http://www.geoapi.org/3.0/javadoc/org/opengis/util/NameFactory.html) from
- * \ref GeoAPI
+ * (http://www.geoapi.org/3.0/javadoc/org.opengis.geoapi/org/opengis/util/NameFactory.html)
+ * from \ref GeoAPI
  */
 class NameFactory {
   public:
